function [fig_out, axes_out, plot_out] = sm(w, varargin)

% sliceomatic    Plots 3D dataset using sliceomatic
%
% Syntax:
%   >> sliceomatic (w)
%   >> sliceomatic (w,['property','value','property','value',...])
%
% Accepts many of the property value pairs that libisis accepts. See
% libisis documentation for further information
%
%--------------
% ISONORMALS
%--------------
% 
% By default isonormals are not calculated to save time. Calculating Isonormals allow
% one to plot isosurfaces in the sliceomatic plot. To activate this
% feature, use the following syntax:
%
% >> plot(w,'isonormals',true, ['property','value','property','value',...])
%
% 
% NOTES:
%
% - Ensure that the slice color plotting is in 'texture' mode -
%      On the 'AllSlices' menu click 'Color Texture'. No indication will
%      be made on this menu to show that it has been selected, but you can
%      see the result if you right-click on an arrow indicating a slice on
%      the graphics window.
%
% - To set the default for future Sliceomatic sessions - 
%      On the 'Object_Defaults' menu select 'Slice Color Texture'

tot = numel(varargin);


if ( tot == 2)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_plot_threed(w,'sliceomatic','xlim',[varargin{1},varargin{2}]);
    else
        [figureHandle_,axesHandle_,plotHandle_] = uib_plot_threed(w,'sliceomatic',varargin{:});
    end
elseif (tot == 4)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}) && isnumeric(varargin{3}) && isnumeric(varargin{4}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_plot_threed(w,'sliceomatic','xlim',[varargin{1},varargin{2}],'ylim',[varargin{3},varargin{4}]);
    else
        [figureHandle_,axesHandle_,plotHandle_] = uib_plot_threed(w,'sliceomatic',varargin{:});
    end    
elseif (tot==6)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}) && isnumeric(varargin{3}) && isnumeric(varargin{4})&& isnumeric(varargin{5}) && isnumeric(varargin{6}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_plot_threed(w,'sliceomatic','xlim',[varargin{1},varargin{2}],'ylim',[varargin{3},varargin{4}],'clim',[varargin{5},varargin{6}]);
    else
        [figureHandle_,axesHandle_,plotHandle_] = uib_plot_threed(w,'sliceomatic',varargin{:});
    end
else
    [figureHandle_,axesHandle_,plotHandle_] = uib_plot_threed(w,'sliceomatic',varargin{:});    
end

if nargout > 0
    fig_out = figureHandle_;
    axes_out = axesHandle_;
    plot_out = plotHandle_;
end
